package models

type VmSchedules struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`

	DeviceZone           DeviceZone             `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber         DeviceNumber           `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DialysisOrder        DialysisOrder          `json:"order" gorm:"foreignkey:DialysisDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	XtPatients           XtPatients             `json:"patient" gorm:"foreignkey:ID;AssociationForeignKey:PatientId;"`
	DoctorAdvice         []*DoctorAdvice        `json:"doctoradvice" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	DialysisPrescription DialysisPrescription   `json:"prescription" gorm:"foreignkey:RecordDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	HisDoctorAdviceInfo  []*HisDoctorAdviceInfo `json:"hisdoctoradviceinfo" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	DialysisSolution     []*DialysisSolution    `json:"dialysissolution" gorm:"foreignkey:RecordDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
}

func (VmSchedules) TableName() string {
	return "xt_schedule"
}

type Schedule struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`

	Patient      string       `gorm:"-" json:"patient" form:"patient"`
	DeviceZone   DeviceZone   `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber DeviceNumber `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`

	TreatmentMode             TreatmentMode        `json:"mode" gorm:"foreignkey:ModeId"`
	DialysisOrder             DialysisOrder        `json:"order" gorm:"foreignkey:DialysisDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	DialysisPrescription      DialysisPrescription `json:"dialysis_prescription" gorm:"foreignkey:RecordDate,PatientId;AssociationForeignKey:RecordDate,PatientId;"`
	PatientInfectiousDiseases []InfectiousDiseases `json:"patient_contagions" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisMachineName       string               `gorm:"column:dialysis_machine_name" json:"dialysis_machine_name" form:"dialysis_machine_name"`
}

func (Schedule) TableName() string {
	return "xt_schedule"
}

type SchedulePatients struct {
	ID           int64              `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64              `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64              `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64              `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64              `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64              `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64              `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64              `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64              `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64              `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64              `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64              `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64              `gorm:"column:is_export" json:"is_export" form:"is_export"`
	Patient      PatientListForFace `json:"patient" gorm:"foreignkey:ID;AssociationForeignKey:PatientId;"`
}

func (SchedulePatients) TableName() string {
	return "xt_schedule"
}

type PatientSchedule struct {
	Schedule

	DeviceZone   DeviceZone   `json:"zone" gorm:"foreignkey:PartitionId"`
	DeviceNumber DeviceNumber `json:"bed" gorm:"foreignkey:BedId"`

	Week int64 `gorm:"-" json:"week" form:"week"`

	TreatmentMode TreatmentMode `json:"mode" gorm:"foreignkey:ModeId"`
}

type Partition struct {
	DeviceZone

	Jihaos []DeviceNumber `json:"jihaos" gorm:"foreignkey:ZoneID"`
}

type Search_Schedule struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`

	Patient string `gorm:"-" json:"patient" form:"patient"`
}

func (Search_Schedule) TableName() string {
	return "xt_schedule"
}

type WeekSchedule struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DialysisMachineName        string                     `gorm:"column:dialysis_machine_name" json:"dialysis_machine_name" form:"dialysis_machine_name"`
	Patient                    string                     `gorm:"-" json:"patient" form:"patient"`
	DeviceZone                 DeviceZone                 `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber               DeviceNumber               `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DialysisPrescription       DialysisSolution           `json:"prescription" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
	DoctorAdvice               []*DoctorAdvice            `json:"doctoradvice" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	HisDoctorAdviceInfo        []*HisDoctorAdviceInfo     `json:"hisdoctoradviceinfo" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	Solution                   []*DialysisSolution        `json:"solution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
	DialysisSolution           DialysisSolution           `json:"dialysissolution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
	XtAssessmentBeforeDislysis XtAssessmentBeforeDislysis `json:"assessmentbefor" gorm:"foreignkey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate"`
}

func (WeekSchedule) TableName() string {
	return "xt_schedule"
}

type ScheduleTemplate struct {
	ID         int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId  int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	TemplateId int64 `gorm:"column:template_id" json:"template_id" form:"template_id"`
	Status     int64 `gorm:"column:status" json:"status" form:"status"`
	Ctime      int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime      int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
}

func (ScheduleTemplate) TableName() string {
	return "xt_schedule_template"
}

type XtDataPrint struct {
	ID        int64 `gorm:"column:id" json:"id" form:"id"`
	IsOpen    int64 `gorm:"column:is_open" json:"is_open" form:"is_open"`
	Status    int64 `gorm:"column:status" json:"status" form:"status"`
	UserOrgId int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Ctime     int64 `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime     int64 `gorm:"column:mtime" json:"mtime" form:"mtime"`
}

func (XtDataPrint) TableName() string {
	return "xt_data_print"
}

type VmSchedulesRemind struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`

	DeviceZone                 DeviceZone                 `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber               DeviceNumber               `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DialysisOrder              DialysisOrder              `json:"order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	XtPatients                 XtPatients                 `json:"patient" gorm:"foreignkey:ID;AssociationForeignKey:PatientId;"`
	DoctorAdvice               []*DoctorAdvice            `json:"doctoradvice" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisPrescription       NewDialysisPrescription    `json:"prescription" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	HisDoctorAdviceInfo        []*HisDoctorAdviceInfo     `json:"hisdoctoradviceinfo" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisSolution           DialysisSolution           `json:"dialysissolution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId;"`
	XtAssessmentBeforeDislysis XtAssessmentBeforeDislysis `json:"assessmentbefor" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	LastAfterWeight            AssessmentAfterDislysis    `gorm:"ForeignKey:PatientID;AssociationForeignKey:PatientID" json:"lastafterweight"`
	XtDialysisOrderSix         XtDialysisOrderSix         `json:"dialysis_order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
}

func (VmSchedulesRemind) TableName() string {
	return "xt_schedule"
}

type WeekScheduleSix struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	IdCardNo                   string                     `gorm:"-" json:"id_card_no" form:"id_card_no"`
	Gender                     string                     `gorm:"-" json:"gender" form:"gender"`
	Phone                      string                     `gorm:"-" json:"phone" form:"phone"`
	DialysisNo                 string                     `gorm:"-" json:"dialysis_no" form:"dialysis_no"`
	Patient                    string                     `gorm:"-" json:"patient" form:"patient"`
	DeviceZone                 DeviceZone                 `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber               DeviceNumber               `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DoctorAdvice               []*DoctorAdvice            `json:"doctoradvice" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	HisDoctorAdviceInfo        []*HisDoctorAdviceInfo     `json:"hisdoctoradviceinfo" gorm:"foreignkey:AdviceDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	DialysisSolution           DialysisSolution           `json:"dialysissolution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
	XtAssessmentBeforeDislysis XtAssessmentBeforeDislysis `json:"assessmentbefor" gorm:"foreignkey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate"`
	XtDialysisOrderSix         XtDialysisOrderSix         `json:"dialysis_order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisPrescription       NewDialysisPrescription    `json:"prescription" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
}

func (WeekScheduleSix) TableName() string {
	return "xt_schedule"
}

type BlodSchedule struct {
	ID                        int64                     `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                 int64                     `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId               int64                     `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                     int64                     `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                 int64                     `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate              int64                     `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType              int64                     `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek              int64                     `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                    int64                     `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                    int64                     `gorm:"column:status" json:"status" form:"status"`
	VmBloodPatients           VmBloodPatients           `json:"patient" gorm:"foreignkey:ID;AssociationForeignKey:PatientId;"`
	BloodDialysisOrder        BloodPatientDialysisOrder `json:"order" gorm:"foreignkey:DialysisDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
	BloodDialysisPrescription BloodDialysisPrescription `json:"prescription" gorm:"foreignkey:RecordDate,PatientId;AssociationForeignKey:RecordDate,PatientId;"`
}

func (BlodSchedule) TableName() string {
	return "xt_schedule"
}

type BloodPatientDialysisOrder struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	DialysisDate int64 `gorm:"column:dialysis_date" json:"dialysis_date" form:"dialysis_date"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Stage        int64 `gorm:"column:stage" json:"stage" form:"stage"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
}

func (BloodPatientDialysisOrder) TableName() string {
	return "xt_dialysis_order"
}

type BloodPatientDialysisPrescription struct {
	ID                         int64  `gorm:"column:id" json:"id" form:"id"`
	PatientId                  int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	MachineType                string `gorm:"column:machine_type" json:"machine_type" form:"machine_type"`
	ModeId                     int64  `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	DialysisDialyszers         string `gorm:"column:dialysis_dialyszers" json:"dialysis_dialyszers" form:"dialysis_dialyszers"`
	DialysisIrrigation         string `gorm:"column:dialysis_irrigation" json:"dialysis_irrigation" form:"dialysis_irrigation"`
	DialyzerPerfusionApparatus string `gorm:"column:dialyzer_perfusion_apparatus" json:"dialyzer_perfusion_apparatus" form:"dialyzer_perfusion_apparatus"`
}

func (BloodPatientDialysisPrescription) TableName() string {
	return "xt_dialysis_prescription"
}

type VmBloodPatients struct {
	ID    int64  `gorm:"column:id" json:"id" form:"id"`
	BedId int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	Name  string `gorm:"column:name" json:"name" form:"name"`
}

func (VmBloodPatients) TableName() string {
	return "xt_patients"
}

type VmBloodSchedule struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DeviceNumber               *NewMDeviceNumberVM        `gorm:"ForeignKey:BedId" json:"device_number"`
	SchedualPatient            *NewMSchedualPatientVMList `gorm:"ForeignKey:PatientId" json:"patient"`
	DialysisSolution           DialysisSolution           `gorm:"ForeignKey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId" json:"dialysis_solution"`
	DialysisPrescription       DialysisPrescription       `gorm:"ForeignKey:PatientId,RecordDate;AssociationForeignKey:PatientId,ScheduleDate" json:"dialysis_prescription"`
	XtAssessmentBeforeDislysis XtAssessmentBeforeDislysis `gorm:"ForeignKey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate" json:"assessment_befor_dislysis"`
	XtDoctorAdvice             XtDoctorAdvice             `gorm:"ForeignKey:PatientId,AdviceDate;AssociationForeignKey:PatientId,ScheduleDate" json:"xt_doctor_advice"`
	HisDoctorAdvice            HisDoctorAdvice            `gorm:"ForeignKey:PatientId,AdviceDate;AssociationForeignKey:PatientId,ScheduleDate" json:"his_doctor_advice"`
	ReceiveTreatmentAsses      ReceiveTreatmentAsses      `gorm:"ForeignKey:PatientId,RecordDate;AssociationForeignKey:PatientId,ScheduleDate" json:"xt_receive_treatment_asses"`
	XtAssessmentAfterDislysis  XtAssessmentAfterDislysis  `gorm:"ForeignKey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate" json:"xt_assesment_after_dislysis"`
	LastAfterWeight            AssessmentAfterDislysis    `gorm:"ForeignKey:PatientID;AssociationForeignKey:PatientID" json:"lastafterweight"`
}

func (VmBloodSchedule) TableName() string {
	return "xt_schedule"
}

type NewMDeviceNumberVM struct {
	DeviceNumber

	Zone *DeviceZone `gorm:"ForeignKey:ZoneID" json:"zone"`
}

func (NewMDeviceNumberVM) TableName() string {
	return "xt_device_number"
}

type NewMSchedualPatientVMList struct {
	ID                 int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId          int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	UserId             int64  `gorm:"column:user_id" json:"user_id" form:"user_id"`
	PatientType        int64  `gorm:"column:patient_type" json:"patient_type" form:"patient_type"`
	DialysisNo         string `gorm:"column:dialysis_no" json:"dialysis_no" form:"dialysis_no"`
	Avatar             string `gorm:"column:avatar" json:"avatar" form:"avatar"`
	Gender             int64  `gorm:"column:gender" json:"gender" form:"gender"`
	Birthday           int64  `gorm:"column:birthday" json:"birthday" form:"birthday"`
	Age                int64  `gorm:"column:age" json:"age"`
	Name               string `gorm:"column:name" json:"name" form:"name"`
	IdCardNo           string `gorm:"column:id_card_no" json:"id_card_no" form:"id_card_no"`
	UserSysBeforeCount int64  `gorm:"column:user_sys_before_count" json:"user_sys_before_count" form:"user_sys_before_count"`
	TrobleShoot        int64  `gorm:"column:troble_shoot" json:"troble_shoot" form:"troble_shoot"`
	Status             int64  `gorm:"column:status" json:"status" form:"status"`
}

func (NewMSchedualPatientVMList) TableName() string {
	return "xt_patients"
}

type VmBloodScheduleTwo struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DeviceNumber               *NewMDeviceNumberVM        `gorm:"ForeignKey:BedId" json:"device_number"`
	SchedualPatient            *NewMSchedualPatientVMList `gorm:"ForeignKey:PatientId" json:"patient"`
	HisPrescriptionTemplateSix HisPrescriptionTemplateSix `gorm:"ForeignKey:PatientId,Mode;AssociationForeignKey:PatientId,ModeId" json:"his_prescription_template"`
}

func (VmBloodScheduleTwo) TableName() string {
	return "xt_schedule"
}

type VmBloodScheduleThree struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DeviceNumber               *NewMDeviceNumberVM        `gorm:"ForeignKey:BedId" json:"device_number"`
	SchedualPatient            *NewMSchedualPatientVMList `gorm:"ForeignKey:PatientId" json:"patient"`
	HisPrescriptionTemplateSix HisPrescriptionTemplateSix `gorm:"ForeignKey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId" json:"his_prescription_template"`
}

func (VmBloodScheduleThree) TableName() string {
	return "xt_schedule"
}

type HisPrescriptionTemplateSix struct {
	ID                             int64                             `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                      int64                             `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PatientId                      int64                             `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Type                           int64                             `gorm:"column:type" json:"type" form:"type"`
	Status                         int64                             `gorm:"column:status" json:"status" form:"status"`
	Ctime                          int64                             `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                          int64                             `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Name                           string                            `gorm:"column:name" json:"name" form:"name"`
	Mode                           int64                             `gorm:"column:mode" json:"mode" form:"mode"`
	HisPrescriptionInfoTemplateSix []*HisPrescriptionInfoTemplateSix `gorm:"ForeignKey:PTemplateId;AssociationForeignKey:ID" json:"his_prescription_info"`
}

func (HisPrescriptionTemplateSix) TableName() string {
	return "his_prescription_template"
}

type HisPrescriptionInfoTemplateSix struct {
	ID                                  int64                                  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                           int64                                  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	RecordDate                          int64                                  `gorm:"column:record_date" json:"record_date" form:"record_date"`
	PatientId                           int64                                  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	Status                              int64                                  `gorm:"column:status" json:"status" form:"status"`
	Ctime                               int64                                  `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime                               int64                                  `gorm:"column:mtime" json:"mtime" form:"mtime"`
	Type                                int64                                  `gorm:"column:type" json:"type" form:"type"`
	Creator                             int64                                  `gorm:"column:creator" json:"creator" form:"creator"`
	Modifier                            int64                                  `gorm:"column:modifier" json:"modifier" form:"modifier"`
	PType                               int64                                  `gorm:"column:p_type" json:"p_type" form:"p_type"`
	PTemplateId                         int64                                  `gorm:"column:p_template_id" json:"p_template_id" form:"p_template_id"`
	HisPrescriptionProjectTemplateSeven []*HisPrescriptionProjectTemplateSeven `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"project"`
	HisPrescriptionAdviceTemplate       []*HisPrescriptionAdviceTemplate       `gorm:"ForeignKey:PrescriptionId;AssociationForeignKey:ID" json:"his_advice"`
	MedType                             string                                 `gorm:"column:med_type" json:"med_type" form:"med_type"`
}

func (HisPrescriptionInfoTemplateSix) TableName() string {
	return "his_prescription_info_template"
}

type HisPrescriptionProjectTemplateSeven struct {
	ID                 int64         `gorm:"column:id" json:"id" form:"id"`
	ProjectId          int64         `gorm:"column:project_id" json:"project_id" form:"project_id"`
	Price              float64       `gorm:"column:price" json:"price" form:"price"`
	UserOrgId          int64         `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	Status             int64         `gorm:"column:status" json:"status" form:"status"`
	Ctime              int64         `gorm:"column:ctime" json:"ctime" form:"ctime"`
	Mtime              int64         `gorm:"column:mtime" json:"mtime" form:"mtime"`
	PatientId          int64         `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	HisPatientId       int64         `gorm:"column:his_patient_id" json:"his_patient_id" form:"his_patient_id"`
	RecordDate         int64         `gorm:"column:record_date" json:"record_date" form:"record_date"`
	Count              string        `gorm:"column:count" json:"count" form:"count"`
	FeedetlSn          string        `gorm:"column:feedetl_sn" json:"feedetl_sn" form:"feedetl_sn"`
	MedListCodg        string        `gorm:"column:med_list_codg" json:"med_list_codg" form:"med_list_codg"`
	SingleDose         string        `gorm:"column:single_dose" json:"single_dose" form:"single_dose"`
	DeliveryWay        string        `gorm:"column:delivery_way" json:"delivery_way" form:"delivery_way"`
	ExecutionFrequency string        `gorm:"column:execution_frequency" json:"execution_frequency" form:"execution_frequency"`
	Day                string        `gorm:"column:day" json:"day" form:"day"`
	Remark             string        `gorm:"column:remark" json:"remark" form:"remark"`
	Unit               string        `gorm:"column:unit" json:"unit" form:"unit"`
	Type               int64         `gorm:"column:type" json:"type" form:"type"`
	PrescriptionId     int64         `gorm:"column:prescription_id" json:"prescription_id" form:"prescription_id"`
	GoodInfo           GoodInfoNight `gorm:"ForeignKey:ID;AssociationForeignKey:ProjectId" json:"good_info"`
	FrequencyType      int64         `gorm:"column:frequency_type" json:"frequency_type" form:"frequency_type"`
	DayCount           int64         `gorm:"column:day_count" json:"day_count" form:"day_count"`
	WeekDay            string        `gorm:"column:week_day" json:"week_day" form:"week_day"`
}

func (HisPrescriptionProjectTemplateSeven) TableName() string {
	return "his_prescription_project_template"
}

type GoodInfoNight struct {
	ID                int64  `gorm:"column:id" json:"id" form:"id"`
	GoodName          string `gorm:"column:good_name" json:"good_name" form:"good_name"`
	SpecificationName string `gorm:"column:specification_name" json:"specification_name" form:"specification_name"`
	GoodTypeId        int64  `gorm:"column:good_type_id" json:"good_type_id" form:"good_type_id"`
}

func (GoodInfoNight) TableName() string {
	return "xt_good_information"
}

type ScheduleTwenty struct {
	ID                  int64               `gorm:"column:id" json:"id" form:"id"`
	UserOrgId           int64               `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId         int64               `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId               int64               `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId           int64               `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate        int64               `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType        int64               `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek        int64               `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId              int64               `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status              int64               `gorm:"column:status" json:"status" form:"status"`
	CreatedTime         int64               `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime         int64               `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport            int64               `gorm:"column:is_export" json:"is_export" form:"is_export"`
	Patient             string              `gorm:"-" json:"patient" form:"patient"`
	DeviceZone          DeviceZone          `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber        DeviceNumber        `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	TreatmentMode       TreatmentMode       `json:"mode" gorm:"foreignkey:ModeId"`
	DialysisOrderTwenty DialysisOrderTwenty `json:"order" gorm:"foreignkey:DialysisDate,PatientId;AssociationForeignKey:ScheduleDate,PatientId;"`
}

func (ScheduleTwenty) TableName() string {
	return "xt_schedule"
}

type ScheduleTwentyOne struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
}

func (ScheduleTwentyOne) TableName() string {
	return "xt_schedule"
}

type VmBloodScheduleOne struct {
	ID              int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId       int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId     int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId           int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId       int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate    int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType    int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek    int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId          int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status          int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime     int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime     int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport        int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DeviceNumber    *NewMDeviceNumberVM        `gorm:"ForeignKey:BedId" json:"device_number"`
	SchedualPatient *NewMSchedualPatientVMList `gorm:"ForeignKey:PatientId" json:"patient"`
	XtDoctorAdvice  []*XtDoctorAdvice          `gorm:"ForeignKey:PatientId,AdviceDate;AssociationForeignKey:PatientId,ScheduleDate" json:"xt_doctor_advice"`
	HisDoctorAdvice []*HisDoctorAdviceFourty   `gorm:"ForeignKey:PatientId,AdviceDate;AssociationForeignKey:PatientId,ScheduleDate" json:"his_doctor_advice"`
}

func (VmBloodScheduleOne) TableName() string {
	return "xt_schedule"
}

type VmNewSchedulesRemind struct {
	ID           int64 `gorm:"column:id" json:"id" form:"id"`
	UserOrgId    int64 `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId  int64 `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId        int64 `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId    int64 `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate int64 `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType int64 `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek int64 `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId       int64 `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status       int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedTime  int64 `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime  int64 `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport     int64 `gorm:"column:is_export" json:"is_export" form:"is_export"`

	DeviceZone                 DeviceZone                    `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber               DeviceNumber                  `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DialysisOrder              NewDialysisOrder              `json:"order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	XtPatients                 XtNewPatients                 `json:"patient" gorm:"foreignkey:ID;AssociationForeignKey:PatientId;"`
	DoctorAdvice               []*DoctorAdvice               `json:"doctoradvice" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisPrescription       DialysisPrescription          `json:"prescription" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	HisDoctorAdviceInfo        []*HisDoctorAdviceInfo        `json:"hisdoctoradviceinfo" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisSolution           NewDialysisSolution           `json:"dialysissolution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId;"`
	XtAssessmentBeforeDislysis XtNewAssessmentBeforeDislysis `json:"assessmentbefor" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	LastAfterWeight            NewAssessmentAfterDislysis    `gorm:"ForeignKey:PatientID;AssociationForeignKey:PatientID" json:"lastafterweight"`
	XtDialysisOrderSix         XtDialysisOrderSix            `json:"dialysis_order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
}

func (VmNewSchedulesRemind) TableName() string {
	return "xt_schedule"
}

type WeekScheduleSeven struct {
	ID                         int64                      `gorm:"column:id" json:"id" form:"id"`
	UserOrgId                  int64                      `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId                int64                      `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId                      int64                      `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId                  int64                      `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate               int64                      `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType               int64                      `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek               int64                      `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId                     int64                      `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status                     int64                      `gorm:"column:status" json:"status" form:"status"`
	CreatedTime                int64                      `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime                int64                      `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport                   int64                      `gorm:"column:is_export" json:"is_export" form:"is_export"`
	IdCardNo                   string                     `gorm:"-" json:"id_card_no" form:"id_card_no"`
	Gender                     string                     `gorm:"-" json:"gender" form:"gender"`
	Phone                      string                     `gorm:"-" json:"phone" form:"phone"`
	DialysisNo                 string                     `gorm:"-" json:"dialysis_no" form:"dialysis_no"`
	Patient                    string                     `gorm:"-" json:"patient" form:"patient"`
	DeviceZone                 DeviceZone                 `json:"zone" gorm:"foreignkey:ID;AssociationForeignKey:PartitionId;"`
	DeviceNumber               DeviceNumber               `json:"number" gorm:"foreignkey:ID;AssociationForeignKey:BedId;"`
	DialysisSolution           DialysisSolution           `json:"dialysissolution" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
	XtAssessmentBeforeDislysis XtAssessmentBeforeDislysis `json:"assessmentbefor" gorm:"foreignkey:PatientId,AssessmentDate;AssociationForeignKey:PatientId,ScheduleDate"`
	XtDialysisOrderSix         XtDialysisOrderSix         `json:"dialysis_order" gorm:"foreignkey:PatientId;AssociationForeignKey:PatientId;"`
	DialysisPrescription       NewDialysisPrescription    `json:"prescription" gorm:"foreignkey:PatientId,ModeId;AssociationForeignKey:PatientId,ModeId"`
}

func (WeekScheduleSeven) TableName() string {
	return "xt_schedule"
}

type ScheduleNewPatients struct {
	ID                  int64  `gorm:"column:id" json:"id" form:"id"`
	UserOrgId           int64  `gorm:"column:user_org_id" json:"user_org_id" form:"user_org_id"`
	PartitionId         int64  `gorm:"column:partition_id" json:"partition_id" form:"partition_id"`
	BedId               int64  `gorm:"column:bed_id" json:"bed_id" form:"bed_id"`
	PatientId           int64  `gorm:"column:patient_id" json:"patient_id" form:"patient_id"`
	ScheduleDate        int64  `gorm:"column:schedule_date" json:"schedule_date" form:"schedule_date"`
	ScheduleType        int64  `gorm:"column:schedule_type" json:"schedule_type" form:"schedule_type"`
	ScheduleWeek        int64  `gorm:"column:schedule_week" json:"schedule_week" form:"schedule_week"`
	ModeId              int64  `gorm:"column:mode_id" json:"mode_id" form:"mode_id"`
	Status              int64  `gorm:"column:status" json:"status" form:"status"`
	CreatedTime         int64  `gorm:"column:created_time" json:"created_time" form:"created_time"`
	UpdatedTime         int64  `gorm:"column:updated_time" json:"updated_time" form:"updated_time"`
	IsExport            int64  `gorm:"column:is_export" json:"is_export" form:"is_export"`
	DialysisMachineName string `gorm:"column:dialysis_machine_name" json:"dialysis_machine_name" form:"dialysis_machine_name"`
}

func (ScheduleNewPatients) TableName() string {
	return "xt_schedule"
}
